| file                      | function                                             | statements | missing | excluded | coverage |
| ------------------------- | ---------------------------------------------------- | ---------- | ------- | -------- | -------- |
| recursivist\cli.py        | visualize                                            | 53         | 4       | 0        | 92%      |
| recursivist\cli.py        | export                                               | 71         | 15      | 0        | 79%      |
| recursivist\cli.py        | compare                                              | 52         | 15      | 0        | 71%      |
| recursivist\cli.py        | main                                                 | 1          | 1       | 0        | 0%       |
| recursivist\cli.py        | (no function)                                        | 30         | 1       | 0        | 97%      |
| recursivist\compare.py    | build_comparison_tree                                | 288        | 159     | 0        | 45%      |
| recursivist\compare.py    | display_comparison                                   | 82         | 14      | 0        | 83%      |
| recursivist\compare.py    | \_export_comparison_to_html                          | 79         | 26      | 0        | 67%      |
| recursivist\compare.py    | \_export_comparison_to_html.\_build_html_tree        | 224        | 108     | 0        | 52%      |
| recursivist\core.py       | generate_color_for_extension                         | 8          | 1       | 0        | 88%      |
| recursivist\core.py       | get_directory_structure                              | 106        | 13      | 0        | 88%      |
| recursivist\core.py       | sort_files_by_type                                   | 43         | 16      | 0        | 63%      |
| recursivist\core.py       | sort_files_by_type.get_size                          | 10         | 4       | 0        | 60%      |
| recursivist\core.py       | sort_files_by_type.get_loc                           | 3          | 1       | 0        | 67%      |
| recursivist\core.py       | sort_files_by_type.get_mtime                         | 9          | 3       | 0        | 67%      |
| recursivist\core.py       | build_tree                                           | 125        | 59      | 0        | 53%      |
| recursivist\core.py       | display_tree                                         | 32         | 8       | 0        | 75%      |
| recursivist\core.py       | count_lines_of_code                                  | 11         | 5       | 0        | 55%      |
| recursivist\core.py       | get_file_size                                        | 5          | 3       | 0        | 40%      |
| recursivist\core.py       | get_file_mtime                                       | 5          | 3       | 0        | 40%      |
| recursivist\core.py       | format_timestamp                                     | 12         | 3       | 0        | 75%      |
| recursivist\exports.py    | sort_files_by_type                                   | 43         | 7       | 0        | 84%      |
| recursivist\exports.py    | sort_files_by_type.get_size                          | 10         | 6       | 0        | 40%      |
| recursivist\exports.py    | sort_files_by_type.get_loc                           | 3          | 1       | 0        | 67%      |
| recursivist\exports.py    | sort_files_by_type.get_mtime                         | 9          | 6       | 0        | 33%      |
| recursivist\exports.py    | DirectoryExporter.to_txt                             | 24         | 6       | 0        | 75%      |
| recursivist\exports.py    | DirectoryExporter.to_txt.\_build_txt_tree            | 117        | 56      | 0        | 52%      |
| recursivist\exports.py    | DirectoryExporter.to_json                            | 10         | 3       | 0        | 70%      |
| recursivist\exports.py    | DirectoryExporter.to_json.convert_structure_for_json | 63         | 28      | 0        | 56%      |
| recursivist\exports.py    | DirectoryExporter.to_html                            | 27         | 9       | 0        | 67%      |
| recursivist\exports.py    | DirectoryExporter.to_html.\_build_html_tree          | 99         | 55      | 0        | 44%      |
| recursivist\exports.py    | DirectoryExporter.to_markdown                        | 23         | 9       | 0        | 61%      |
| recursivist\exports.py    | DirectoryExporter.to_markdown.\_build_md_tree        | 98         | 55      | 0        | 44%      |
| recursivist\exports.py    | DirectoryExporter.to_jsx                             | 5          | 3       | 0        | 40%      |
| recursivist\jsx_export.py | generate_jsx_component                               | 95         | 42      | 0        | 56%      |
| recursivist\jsx_export.py | generate_jsx_component.\_build_structure_jsx         | 172        | 107     | 0        | 38%      |
